@@ -3,7 +3,7 @@ use structopt::StructOpt;
 use terra_rust_api::Terra;
 
 use crate::{NAME, VERSION};
-use bitcoin::secp256k1::Secp256k1;
+use secp256k1::Secp256k1;
 use terra_rust_api::messages::distribution::{
     MsgWithdrawDelegationReward, MsgWithdrawValidatorCommission,
 };
@@ -15,7 +15,7 @@ use terra_rust_wallet::Wallet;
 pub enum DistributionCommand {
     #[structopt(name = "withdraw-reward")]
     /// Withdraw delegation reward
-    WithdrawReward {
+    Reward {
         /// delegator. The nickname in the wallet used to sign the transaction, and transfer the initial amount
         delegator: String,
         #[structopt(
@@ -27,7 +27,7 @@ pub enum DistributionCommand {
     },
     #[structopt(name = "withdraw-commission")]
     /// Withdraw commission
-    WithdrawCommission {
+    Commission {
         /// delegator. The nickname in the wallet used to sign the transaction, and transfer the initial amount
         delegator: String,
         #[structopt(name = "validator", help = "the validator's terravaloper address.")]
@@ -42,15 +42,15 @@ pub enum DistributionCommand {
     },
 }
 
-pub async fn distribution_cmd_parse<'a>(
-    terra: &Terra<'a>,
-    wallet: &Wallet<'a>,
+pub async fn distribution_cmd_parse(
+    terra: &Terra,
+    wallet: &Wallet<'_>,
     seed: Option<&str>,
     cmd: DistributionCommand,
 ) -> Result<()> {
     let secp = Secp256k1::new();
     match cmd {
-        DistributionCommand::WithdrawReward {
+        DistributionCommand::Reward {
             delegator,
             validator,
         } => {
@@ -61,13 +61,13 @@ pub async fn distribution_cmd_parse<'a>(
             match validator {
                 Some(v) => {
                     log::info!("Validator {}", &v);
-                    let msg = MsgWithdrawDelegationReward::create(delegator_account, v);
+                    let msg = MsgWithdrawDelegationReward::create(delegator_account, v)?;
                     let messages: Vec<Message> = vec![msg];
                     let resp = terra
                         .submit_transaction_sync(
                             &secp,
                             &delegator_key,
-                            &messages,
+                            messages,
                             Some(format!(
                                 "PFC-{}/{}",
                                 NAME.unwrap_or("TERRARUST"),
@@ -83,7 +83,7 @@ pub async fn distribution_cmd_parse<'a>(
             }
             Ok(())
         }
-        DistributionCommand::WithdrawCommission {
+        DistributionCommand::Commission {
             delegator,
             validator,
         } => {
@@ -91,13 +91,13 @@ pub async fn distribution_cmd_parse<'a>(
             let delegator_key = wallet.get_private_key(&secp, &delegator, seed)?;
 
             log::info!("Validator {}", &validator);
-            let msg = MsgWithdrawValidatorCommission::create(validator);
+            let msg = MsgWithdrawValidatorCommission::create(validator)?;
             let messages: Vec<Message> = vec![msg];
             let resp = terra
                 .submit_transaction_sync(
                     &secp,
                     &delegator_key,
-                    &messages,
+                    messages,
                     Some(format!(
                         "PFC-{}/{}",
                         NAME.unwrap_or("TERRARUST"),
@@ -120,14 +120,14 @@ pub async fn distribution_cmd_parse<'a>(
             let validator = delegator_key.public_key(&secp).operator_address()?;
 
             log::info!("Validator {}", &validator);
-            let msg_commission = MsgWithdrawValidatorCommission::create(validator.clone());
-            let msg_rewards = MsgWithdrawDelegationReward::create(delegator_account, validator);
+            let msg_commission = MsgWithdrawValidatorCommission::create(validator.clone())?;
+            let msg_rewards = MsgWithdrawDelegationReward::create(delegator_account, validator)?;
             let messages: Vec<Message> = vec![msg_commission, msg_rewards];
             let resp = terra
                 .submit_transaction_sync(
                     &secp,
                     &delegator_key,
-                    &messages,
+                    messages,
                     Some(format!(
                         "PFC-{}/{}",
                         NAME.unwrap_or("TERRARUST"),
