@@ -3,7 +3,7 @@ use std::io::{self, BufRead};
 use structopt::StructOpt;
 use terra_rust_api::{PrivateKey, Terra};
 //use crate::errors::Result;
-use bitcoin::secp256k1::Secp256k1;
+use secp256k1::Secp256k1;
 use terra_rust_wallet::Wallet;
 
 #[derive(StructOpt)]
@@ -74,7 +74,7 @@ pub fn key_cmd_parse(
 
             let pk = match seed {
                 Some(seed_str) => PrivateKey::from_words_seed(&secp, &words, seed_str)?,
-                None => PrivateKey::from_words(&secp, &words)?,
+                None => PrivateKey::from_words(&secp, &words, 0, 0)?,
             };
             wallet.store_key(&name, &pk)?;
         }
